#ifndef _FRAME_H
#define _FRAME_H

#include "wx.h"
#include "BasicFrame.h"


/* Version 2 of the Frame class */

/* This class captures the concept of a framed window that appears on
   a graphical user interface. A Frame object is named so that mouse
   events can be associated with a given Frame. A Frame can be manipulated 
   by the program to change its location and shape. A Frame can display
   text and be erased.

*/


class Frame {
private:

   BasicFrame *frame;               // hidden implementation
   char       *name;                // title on visible frame
   int         xCoord,yCoord;       // location of upper left hand corner
   int         height, width;       // shape of the frame

   void CreateIfNeeded();

public:

   Frame(char *name, int x, int y, int w, int h);
   Frame(char* name, int x, int y);
   Frame(char* name);
   Frame();
            
   void  MoveTo(int newX, int newY);           // change position
   void  Resize(int newW, int newH);           // change shape
   void  Resize(float factor);                 // change shape
   void  DrawText(char* msg, int x,  int  y);  // display msg at (x,y)
   void  TextSize (char* msg, int& w, int& h); // find size of msg
   void  DrawLine(int x1, int y1,              // draw line from (x1, y1) 
                  int x2, int y2);             //           to   (x2, y2)
   void  DrawCircle(int x, int y, int r);      // draw circle with radius r
                                               // and center at (x,y)
   void  Clear();                              // clear entire display area
   void  Clear(int x, int y, int w, int h);    // clear selected region
   int   IsNamed(char* n);                     // is this your name?

  ~Frame();
};


#endif







