#ifndef _FILECHOOSER_H
#define _FILECHOOSER_H

#include "File.h"

/*
CLASS
      FileChooser

    The objects of this class can conduct a modal dialogue with the
    user for the purpose of obtaining a File. The user is
    presented with a list of names of files in a given directory that match
    a specified filter pattern. The user is asked to pick one of the
    filenames in the list.  
*/

class FileChooser {

private:
  char* thePath;
  char* theFilter;

public:

     //////////
     // Construct a FileChooser by specifying the pathname of the
     // directory whose filenames will be filtered according to the
     // specified filter pattern. All filenames matching the filter
     // pattern will be presented to the user when the dialogueis
     // initiated.
     //<UL>
     //<LI><B>path</B>: the pathname of the directory whose filenames
     //will be filtered and presented to the user</LI>
     //<LI><B>filter</B>: the pattern which filenames in the specified
     // directory must math in order to be presented to the user.</LI>
     //</UL>
     FileChooser(char* path, char* filter);   // search at path with filter


     //////////
     // Construct a FileChooser by specifying the pathname of the
     // directory whose filenames will be presented to the user 
     // when the dialogue is initiated. No filtering of the filenames
     // is performed.
     //<UL>
     //<LI><B>path</B>: the pathname of the directory whose filenames
     // will be presented to the user. No filtering will be done.</LI>
     //</UL>
     FileChooser(char* path);                 // search at path, no filter

     //////////
     // Construct a FileChooser that presents all the filenames in
     // the user's current working directory. 
     FileChooser();                           // search at CWD, no filter

     //////////
     // Initiate the dialogue. This method does not return until the
     // user has dismissed the dialogue box. The method returns a File
     // object describing the result of the users action.
File AskUser();                               // get file via dialog

     //////////
     // Reclaim all resources associated with the FileQuery object when
     // the object is destructed.
    ~FileChooser();                           // clean up
};

#endif
