#ifndef _FRAMEMGR_
#define _FRAMEMGR_

#include "Frame.h"

typedef Frame *(FrameArray);

/*
CLASS
   FrameManager

   A FrameManager maintains a collection of Frame objects and retrieves
   a Frame from the collection by the Frame's name. Methods allow Frames
   to be added and removed.  
*/


class FrameManager {
private:
	FrameArray *frames;
	int last;
	int maxFrames;

public:
        //////////
        // Construct a FrameManager optionally specifying the maximum
        // number of Frames that can be managed. The default maximum
        // is 10.
	FrameManager(int maxFrames = 10);

        //////////
        // Add a Frame to the FrameManager's collection. The Frame to be
        // added is passed by reference. The operation has no effect if
        // the new Frame would exceed the maximum number of Frames that
        // the FrameManager can contain.
	void Add(Frame& frame);

        //////////
        // Add a Frame to the FrameManager's collection. The Frame to be
        // added is passed by pointer. The operation has no effect if
        // the new Frame would exceed the maximum number of Frames that
        // the FrameManager can contain.
	void Add(Frame* frame);

        //////////
        // Return a pointer to a Frame whose name is given by the text
        // string passed as a parameter. A null pointer is returned if
        // a Frame with the required name is not part of the FrameManager's
        // collection. If more than one Frame in the collection has the
        // specified name an arbitrary one of them is returned.
	Frame* FindByName(char* frameName);

        //////////
        // Remove a given Frame from the collection maintained by the
        // FrameManager. The Frame to be removed is identified by 
        // reference. The method has no effect if the specified Frame
        // is not included in the FrameManager's collection.
	void Remove(Frame& frame);

        //////////
        // Remove a given Frame from the collection maintained by the
        // FrameManager. The Frame to be removed is identified by 
        // pointer. The method has no effect if the specified Frame
        // is not included in the FrameManager's collection.
	void Remove(Frame* frame);

        //////////
        // Release all of the resources held by the FrameManager.
        // The individual Frame object maintained by the FrameManager
        // are NOT destructed. Such Frames must be destructed separately.
	~FrameManager();

};

#endif
