#include "Canvas.h"
#include "Base.h"
#include "Program.h"

DrawingCanvas::DrawingCanvas (BasicFrame *frame, Canvas* cvs,
                              int x, int y, int w, int h, 
                              long style): wxCanvas(frame, x, y, w, h, style)
{
  canvas = cvs;
}

void DrawingCanvas::OnEvent( wxMouseEvent& event) {
  float x, y;
  event.Position(&x, &y);
  int keys = 0;
  if (event.leftDown)   keys |= leftButtonDown;
  if (event.rightDown)  keys |= rightButtonDown;
  if (event.middleDown) keys |= middleButtonDown;
  if (event.Dragging()) keys |= isDragging;
  OnMouseEvent(canvas->getName(), (int)x, (int)y , keys);
}

DrawingCanvas::~DrawingCanvas() {}


Canvas::Canvas(Frame& fr, char *nm, Location loc, Shape sh) {
   frame = &fr; 
   name = copystring(nm);
   location = loc; shape = sh;
   dc = (DrawingCanvas*)0;
}

void Canvas::CreateIfNeeded() {
  if (!dc) {
     frame->CreateIfNeeded();
     dc = new DrawingCanvas(frame->frame, this, 
                            location.Xcoord(),  location.Ycoord(), 
                            shape.Width(), shape.Height(),
                            wxRETAINED);
     dc->SetBackground(wxWHITE_BRUSH);
     dc->SetCursor    (new wxCursor(wxCURSOR_PENCIL));
     dc->SetPen       (new wxPen("RED", 3, wxSOLID));
     dc->SetFont      (new wxFont(18, wxROMAN, wxNORMAL, wxNORMAL));
   }
}


void Canvas::DrawText(char *msg, Location loc) 
{
    CreateIfNeeded();
	if(msg == (char*)0) return;
    dc->DrawText(msg, (float)loc.Xcoord(), 
                      (float)loc.Ycoord());
}

Shape Canvas::TextSize(char *msg) 
{
    float wf, hf, descent, leading;
    CreateIfNeeded();
    dc->GetTextExtent(msg, &wf, &hf, &descent, &leading);
    return Shape((int)wf, ((int)hf)+1);
}

void Canvas::DrawLine(Location p1, Location p2) {
    CreateIfNeeded();
    dc->DrawLine((float)(p1.Xcoord()), (float)(p1.Ycoord()),
                 (float)(p2.Xcoord()), (float)(p2.Ycoord()));
}

void Canvas::DrawCircle(Location center, int r) {
    CreateIfNeeded();
    dc->DrawEllipse((float)(center.Xcoord()-r), 
                    (float)(center.Ycoord()-r), 
                    (float)(2*r), (float)(2*r));
}

void Canvas::Clear() {
   CreateIfNeeded();
   dc->Clear();
} 

void Canvas::Clear(Location loc, Shape sh) 
{
    CreateIfNeeded();
    dc->SetClippingRegion((float)loc.Xcoord(),
                          (float)loc.Ycoord(),
                          (float)sh.Width(),
                          (float)sh.Height());
    dc->Clear();
    dc->DestroyClippingRegion();
}


char*  Canvas::getName() { return copystring(name); }


Canvas::~Canvas() {}

void DrawingCanvas::OnPaint(){
  ::OnPaint();
}














