#ifndef _FILEQUERY_H
#define _FILEQUERY_H


#include "File.h"

/*
CLASS
  FileQuery

  This class initiates a modal dialogue with the user to obtain a
  File. The user is presented with a dialogue box into which
  the user types the name of the File. The FileQuery provides a 
  default filename and a filter indicating the type of filename
  desired. However, the filter is not enforced and is given only as
  a hint to the user.
*/
 
class FileQuery {
private:
   char msg[200];                            // prompt to user
   void makeMsg(char* p, char* f);           // private utility routine
public:

   //////////
   // Construct a FileQuery object with the default file name and
   // filter to be given as hints to the user when the dialogue is
   // initiated.
   //<UL>
   //<LI><B>path</B>: the default name given to the user</LI>
   //<LI><B>filter</B>: a pattern suggesting (as a hint) the
   // type of file desired.</LI>
   //</UL>
   FileQuery( char* path, char* filter );    // prompt with path and filter

   //////////
   // Construct a FileQuery object with the default file name to be
   // given as a hint to the user when the dialogue is initiated. The
   // filter hint is a default value.
   //<UL>
   //<LI><B>path</B>: the default name given to the user</LI>
   //</UL>
   FileQuery( char* path );                  // prompt with path default filter

   //////////
   // Construct a FileQuery object with default values for both the
   // filename and filter hints to be shown to the user when the
   // dialogue is initiated.
   FileQuery( );                             // use all defaults

   //////////
   // Initiate the dialogue. This method does not return until the
   // user has dismissed the dialogue box. The method returns a File
   // object describing the result of the users action.
   File AskUser();                           // get file from user via dialog

   //////////
   // Reclaim all resources associated with the FileQuery object when
   // the object is destructed.
  ~FileQuery();
};

#endif
