#ifndef _LOCATION_H
#define _LOCATION_H



class Frame;

/* 
CLASS
   Location

   This class defines the concepts of a Location in a coordinate system
   where the (0,0) position is in the upper left-hand corner. The x-axis
   extends in a positive direction to the right and the y-axis extends in
   a positive direction towards the bottom of the screen.
*/

class Location {			 // Version 2
private:  

     int  currentX, currentY;

public:

     //////////
     // Construct a Location object with the specified x and y coordinates.
     // <UL>
     // <LI><B>x </B>: the x coordinate of the location.
     // <LI><B>y </B>: the y coordinate of the location.
     // </UL>
	Location(int x, int y);	
        
     //////////
     // Construct a Location object at a default location.
        Location();	
		
     //////////
     // Return the current x coordinate of the Location object.
     int Xcoord();   
    		
     //////////
     // Return the current y coordinate of the Location object.
     int Ycoord();  
      		
     //////////
     //  Change the current Location object by replacing its x coordinate
     // with the specified coordinate value.
     //<UL>
     //<LI><B>newX</B>: the new value for this Location object's
     // x coordinate. </LI>
     //</UL>
     void setX(int newX);        
                                        
     //////////
     // Change the current Location object by replacing its y coordinate
     // with the specified coordinate value.
     //<UL>
     //<LI><B>newY</B>: the new value for this Location object's
     // y coordinate. </LI>
     //</UL>
     void setY(int newY);        
           
     //////////
     // Determine if two Location objects refer to the same point.
     // Two Location objects refer to the same point if they have the
     // same values for their x and y coordinates.
     // One Location is the current object and the other Location object
     // is passed as a parameter. This method is declared <I><B>const</B></I>
     // because it does not change the current object (i.e., the object
     // performing this method.
     //<UL>
     //<LI><B>other </B>: the Location object to which the current object
     // is compared. The other Location object is passed by reference and
     // is declared <I><B>const</B></I> because the parameter is not changed
     // by this method.</LI>
     //</UL>
     int isSameAs (const Location& other) const;

     //////////
     // Determine if the point represented by the current Location object
     // is defined in an array of Locations. The array is represented by
     // a pointer to its first element and an integer defining the length
     // of the array. This method is declared <I><B>const</B></I>
     // because it does not change the current object (i.e., the object
     // performing this method.
     //<UL>
     //<LI><B>list </B>: a pointer to the first element of the array of
     // Locations. Neither the <I>list</I> value nor what it points to can be
     // changed as they are both declared as <I><B>const</B></I>. </LI>
     //<LI><B>listLength </B>: the length of the array pointed to by
     // <I>list</I>. </LI>
     //</UL>
     int isInList (const Location* const list,
		   const int listLength) const;


             
};

#endif




