#ifndef _RECTANGLE_FACTORY_
#define _RECTANGLE_FACTORY_

#include "Rectangle3.h"
#include "Shape.h"
#include "Location.h"

/*
CLASS
  RectangleFactory

  This class is a producer of Rectangle3 object all of which are
  constrained to have the same Shape. This class illustrates the
  "factory" concept - an object that manufactures other objects as
  its output.

*/
class RectangleFactory
{
private:
	Shape commonShape;

public:
        
        //////////
        // Construct the factory specifying the Shape that all
        // Rectangles produced by the factory are to have.
        //<UL>
	//<LI><B>shapeForAll </B>: the Shape of all
        // Rectangle3 objects produced by this RectangleFactory.</LI>
        //</UL>
	RectangleFactory(Shape shapeForAll);
        
        //////////
        // Produce a new Rectangle3 object with the Shape common
        // to all Rectangle3 objects produced by this RectangleFactory and
        // a specified Location. The pointer to the new Rectangle3 object   
        // is returned.
        //<UL>
	//<LI><B>location </B>: the Location of the produced
        // Rectangle3 object.</LI>
        //</UL>
	Rectangle3* New(Location location);
        
        //////////
        // Destruct the factory.
	~RectangleFactory();
};

#endif
